@@ -3,8 +3,11 @@ Main interface for cloud9 service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.cloud9 import (
+
+    from mypy_boto3_cloud9 import Cloud9Client
+    from mypy_boto3_cloud9 import (
         DescribeEnvironmentMembershipsPaginator,
         ListEnvironmentsPaginator,
     )
@@ -13,6 +16,7 @@ Usage::
 
     describe_environment_memberships_paginator: DescribeEnvironmentMembershipsPaginator = client.get_paginator("describe_environment_memberships")
     list_environments_paginator: ListEnvironmentsPaginator = client.get_paginator("list_environments")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
@@ -35,7 +39,7 @@ __all__ = ("DescribeEnvironmentMembershipsPaginator", "ListEnvironmentsPaginator
 
 class DescribeEnvironmentMembershipsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEnvironmentMemberships documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships)
+    [Paginator.DescribeEnvironmentMemberships documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships)
     """
 
     def paginate(
@@ -46,18 +50,18 @@ class DescribeEnvironmentMembershipsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeEnvironmentMembershipsResultTypeDef]:
         """
-        [DescribeEnvironmentMemberships.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships.paginate)
+        [DescribeEnvironmentMemberships.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships.paginate)
         """
 
 
 class ListEnvironmentsPaginator(Boto3Paginator):
     """
-    [Paginator.ListEnvironments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments)
+    [Paginator.ListEnvironments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListEnvironmentsResultTypeDef]:
         """
-        [ListEnvironments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments.paginate)
+        [ListEnvironments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments.paginate)
         """
