@@ -3,9 +3,11 @@ Main interface for cloud9 service type definitions.
 
 Usage::
 
-    from mypy_boto3.cloud9.type_defs import EnvironmentLifecycleTypeDef
+    ```python
+    from mypy_boto3_cloud9.type_defs import EnvironmentLifecycleTypeDef
 
     data: EnvironmentLifecycleTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
